import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useLayoutEffect, useRef, useState } from 'react';
import * as monaco from 'monaco-editor';
const defaultStyle = {
    width: '100%',
    height: '100%',
};
const defaultOptions = {
    fontSize: 12,
};
export const JSONDisplayer = ({ id, onSave, onError, style, containerStyle, value = '', schema, }) => {
    const [code] = useState(value);
    const containerRef = useRef(null);
    const editor = useRef();
    const subscription = useRef();
    useLayoutEffect(() => {
        initMonaco();
        return () => {
            destoryMonaco();
        };
    }, [schema]);
    useEffect(() => {
        var _a, _b;
        try {
            if (typeof value === 'string') {
                (_b = (_a = editor.current) === null || _a === void 0 ? void 0 : _a.getModel()) === null || _b === void 0 ? void 0 : _b.setValue(value === '' ? value : JSON.stringify(JSON.parse(value), null, '\t'));
            }
        }
        catch (err) {
            console.error(err);
        }
    }, [value]);
    const initMonaco = () => {
        monaco.languages.json.jsonDefaults.setDiagnosticsOptions({
            validate: true,
            schemas: [
                {
                    uri: `http://farrow/${id}-input.json`,
                    schema,
                },
            ],
        });
        editor.current = createEditor(id, containerRef.current, code, defaultOptions, onSave, onError);
    };
    const destoryMonaco = () => {
        if (editor.current) {
            editor.current.dispose();
            const model = editor.current.getModel();
            if (model) {
                model.dispose();
            }
        }
        if (subscription.current) {
            subscription.current.dispose();
        }
    };
    style = Object.assign(Object.assign({}, defaultStyle), style);
    return (_jsx("div", Object.assign({ style: containerStyle }, { children: _jsx("div", { ref: containerRef, style: style }, void 0) }), void 0));
};
const createEditor = (id, container, value, options = {}, onSave, onError) => {
    monaco.languages.json.jsonDefaults.setDiagnosticsOptions({
        validate: true,
        allowComments: true,
        schemaValidation: 'warning',
        schemaRequest: 'warning',
        trailingCommas: 'warning',
    });
    const modelUri = monaco.Uri.parse(`a://b/${id}-output.json`);
    const model = monaco.editor.createModel(value, 'json', modelUri);
    const editor = monaco.editor.create(container, Object.assign(Object.assign({}, options), { value, language: 'json', model, readOnly: true, minimap: {
            enabled: false,
        } }));
    const messageContribution = editor.getContribution('editor.contrib.messageController');
    const diposable = editor.onDidAttemptReadOnlyEdit(() => {
        messageContribution.dispose();
    });
    return editor;
};
export default createEditor;
//# sourceMappingURL=JSONDisplayer.js.map