import { __awaiter } from "tslib";
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { useMemo } from 'react';
import styled from 'styled-components';
import { createApiPipelineWithUrl } from 'farrow-api-client';
import { JSONEditor } from './JSONEditor';
import { JSONDisplayer } from './JSONDisplayer';
import { useAppSelector, useAppDispatch } from './hook';
import { sessionActions } from './store/sessionsSlice';
import { ServiceLinker } from './ServiceLinker';
import { ApiSelect } from './ApiSelect';
export const Playground = () => {
    const sessions = useAppSelector((state) => state.sessions.sessions);
    const id = useAppSelector((state) => state.sessions.activeSessionId);
    return (_jsx(_Fragment, { children: sessions.map((session) => {
            return _jsx(SinglePlayground, { isCurrent: id === session.id, session: session }, session.id);
        }) }, void 0));
};
const findAPI = (apis, name) => {
    for (const api of apis) {
        if (api.name === name)
            return api;
        if (api.children) {
            const result = findAPI(api.children, name);
            if (result)
                return result;
        }
    }
    return null;
};
const fetcher = (request) => __awaiter(void 0, void 0, void 0, function* () {
    const { url, calling, options: init } = request;
    const options = Object.assign(Object.assign({ method: 'POST' }, init), { headers: Object.assign({ 'Content-Type': 'application/json' }, init === null || init === void 0 ? void 0 : init.headers), body: JSON.stringify(calling) });
    const response = yield fetch(url, options);
    const text = yield response.text();
    const json = JSON.parse(text);
    return json;
});
const SinglePlayground = ({ session, isCurrent }) => {
    const id = useAppSelector((state) => state.sessions.activeSessionId);
    const api = useMemo(() => findAPI(session.apis, session.title), [session, session.schema, session.title, session.apis]);
    const dispatch = useAppDispatch();
    const handleInputChange = (content) => {
        if (api) {
            dispatch(sessionActions.updaetInput({ id, input: content, path: api.path }));
        }
    };
    const send = () => {
        if (!api) {
            return;
        }
        const pipeline = createApiPipelineWithUrl(session.servicePath, { fetcher });
        try {
            pipeline
                .invoke({
                type: 'Single',
                path: api.path,
                input: JSON.parse((api === null || api === void 0 ? void 0 : api.input) || '{}'),
            })
                .then((res) => {
                dispatch(sessionActions.setOutput({ id, path: api.path, output: JSON.stringify(res) }));
            })
                .catch((err) => {
                dispatch(sessionActions.setError({ id, path: api.path, error: JSON.stringify(err.message) }));
                console.error(err);
            });
        }
        catch (err) {
            dispatch(sessionActions.setError({ id, path: api.path, error: JSON.stringify(err instanceof Error ? err.message : null) }));
            console.error(err);
        }
    };
    const handleSendClick = () => {
        send();
    };
    return (_jsxs(SinglePlaygroundContainer, Object.assign({ isCurrent: isCurrent }, { children: [_jsx(ServiceLinker, { id: session.id, servicePath: session.servicePath }, void 0), _jsxs(OperatorContainer, { children: [_jsx(ApiSelectWrapper, { children: _jsx(ApiSelect, Object.assign({ api: api }, session), void 0) }, void 0), _jsx(SendButton, Object.assign({ onClick: handleSendClick }, { children: "Send" }), void 0)] }, void 0), _jsx(InputEditorContainer, { children: _jsx(JSONEditor, { id: session.id, current: id, onSave: handleInputChange, value: (api === null || api === void 0 ? void 0 : api.input) || '', style: { width: '100%', height: 'auto', minHeight: '350px', border: '1px solid #d4d4d4' } }, void 0) }, void 0), _jsx(ErrorDisplayer, { children: api === null || api === void 0 ? void 0 : api.error }, void 0), _jsx(OutDisplayerContainer, { children: _jsx(JSONDisplayer, { id: session.id, value: (api === null || api === void 0 ? void 0 : api.output) || '', style: { width: '100%', height: 'auto', minHeight: '450px' } }, void 0) }, void 0)] }), void 0));
};
const ErrorDisplayer = styled.div `
  height: 35px;
  line-height: 35px;
  color: rgb(242, 92, 84);
  text-align: right;
`;
const InputEditorContainer = styled.div ``;
const OutDisplayerContainer = styled.div `
  margin-top: 20px;
`;
const SinglePlaygroundContainer = styled.main `
  display: flex;
  width: 100%;
  animation: ease-in 0.5s ease-out forwards 0.2s;
  padding: 0 10px 40px 10px;
  box-sizing: border-box;
  display: ${({ isCurrent }) => (isCurrent ? 'block' : 'none')};
`;
const OperatorContainer = styled.div `
  display: flex;
  -webkit-box-align: center;
  align-items: center;
  padding: 10px 0;
  justify-content: space-between;
  width: 100%;
`;
const ApiSelectWrapper = styled.div `
  flex: 1 1 0%;
`;
const SendButton = styled.button `
  margin-left: 6px;
  width: 206px;
  box-sizing: border-box;
  border-radius: 3px;
  height: 40px;
  padding: 0 10px 0 10px;
  display: inline-flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  text-align: center;
  font-size: 14px;
  font-weight: normal;
  font-family: 'OpenSans', Helvetica, Arial, sans-serif;
  cursor: default;
  -webkit-user-select: none;
  user-select: none;
  cursor: pointer;
  border: none;
  font-weight: 600;
  color: #fff;
  background: rgb(9, 123, 237);
  &:hover {
    background-color: rgb(40, 143, 247);
  }
  &:active {
    background-color: rgb(20, 133, 246);
  }
`;
//# sourceMappingURL=Playground.js.map