import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useState } from 'react';
import { SortableContainer, SortableElement } from 'react-sortable-hoc';
import styled from 'styled-components';
import { CirclePlug } from './icons';
import { useAppSelector, useAppDispatch } from './hook';
import { sessionActions } from './store/sessionsSlice';
import { Tab } from './Tab';
const SortableTab = SortableElement(Tab);
const TabBarContainer = styled.header `
  height: 57px;
  overflow: hidden;
  background: #fafafa;
  -webkit-app-region: drag;
  &:hover {
    overflow-x: overlay;
  }
`;
const SortableTabBar = SortableContainer(TabBarContainer);
export const TabBar = () => {
    const [sorting, setSorting] = useState(false);
    const sessions = useAppSelector((state) => state.sessions.sessions);
    const dispatch = useAppDispatch();
    const onSortStart = ({}) => {
        setSorting(true);
    };
    const onSortEnd = ({}) => {
        setSorting(false);
    };
    const handlePlusClick = () => {
        console.log('test');
        dispatch(sessionActions.add());
    };
    return (_jsx(SortableTabBar, Object.assign({ axis: "x", lockAxis: "x", lockToContainerEdges: true, distance: 10, transitionDuration: 200, onSortStart: onSortStart, onSortEnd: onSortEnd }, { children: _jsxs(Tabs, { children: [sessions.map((session, index) => {
                    return _jsx(SortableTab, { index: index, id: session.id, title: session.title }, session.id);
                }), _jsx(Plus, Object.assign({ sorting: sorting, onClick: handlePlusClick }, { children: _jsx(CirclePlug, { width: "25px", height: "25px" }, void 0) }), void 0)] }, void 0) }), void 0));
};
const Tabs = styled.div `
  display: flex;
  align-items: center;
  margin-top: 16px;
  background: #fafafa;
  padding-left: ${(p) => (p.isApp ? '43px' : '10px')};
  padding-right: 10px;
`;
const Plus = styled.div `
  -webkit-app-region: no-drag;
  box-sizing: border-box;
  padding: 8px;
  display: flex;
  visibility: ${(p) => (p.sorting ? 'hidden' : 'visible')};
  height: 43px;
  width: 43px;
  border-radius: 4px 4px 0 0;
  border: 1px solid #ccc;
  justify-content: center;
  align-items: center;
  color: #ccc;
  cursor: pointer;
  &:hover {
    & > .icon > path {
      fill: #097bed;
    }
  }
  & > .icon > path {
    fill: #666;
  }
`;
//# sourceMappingURL=TabBar.js.map