import { PayloadAction } from '@reduxjs/toolkit';
import 'immer';
import { FormatResult } from 'farrow-api/dist/toJSON';
import type { RootState } from './index';
export declare type API = {
    name: string;
    path: string[];
    input?: string;
    output?: string;
    loading: boolean;
    error?: string | null;
    title: string;
    description?: string;
    deprecated?: string;
    children?: API[];
};
export declare type Session = {
    id: string;
    servicePath: string;
    title: string;
    schema: FormatResult | null;
    apis: API[];
};
export declare const sessionsSlice: import("@reduxjs/toolkit").Slice<{
    sessions: Session[];
    activeSessionId: string;
}, {
    init: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: sessions }: PayloadAction<Session[]>) => void;
    remove: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: id }: PayloadAction<string>) => void;
    add: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>) => void;
    changeServicePath: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, servicePath } }: {
        payload: {
            id: string;
            servicePath: string;
        };
        type: string;
    }) => void;
    changeSelected: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: id }: PayloadAction<string>) => void;
    sort: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { index, to } }: {
        payload: {
            index: number;
            to: number;
        };
        type: string;
    }) => void;
    updateSchema: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, schema } }: {
        payload: {
            id: string;
            schema: FormatResult;
        };
        type: string;
    }) => void;
    setName: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, name } }: {
        payload: {
            id: string;
            name: string;
        };
        type: string;
    }) => void;
    updaetInput: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, path, input } }: {
        payload: {
            id: string;
            path: string[];
            input: string;
        };
        type: string;
    }) => void;
    setOutput: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, path, output } }: {
        payload: {
            id: string;
            path: string[];
            output: string;
        };
        type: string;
    }) => void;
    setError: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, path, error } }: {
        payload: {
            id: string;
            path: string[];
            error: string | null;
        };
        type: string;
    }) => void;
}, "session">;
export declare const sessionActions: import("@reduxjs/toolkit").CaseReducerActions<{
    init: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: sessions }: PayloadAction<Session[]>) => void;
    remove: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: id }: PayloadAction<string>) => void;
    add: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>) => void;
    changeServicePath: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, servicePath } }: {
        payload: {
            id: string;
            servicePath: string;
        };
        type: string;
    }) => void;
    changeSelected: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: id }: PayloadAction<string>) => void;
    sort: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { index, to } }: {
        payload: {
            index: number;
            to: number;
        };
        type: string;
    }) => void;
    updateSchema: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, schema } }: {
        payload: {
            id: string;
            schema: FormatResult;
        };
        type: string;
    }) => void;
    setName: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, name } }: {
        payload: {
            id: string;
            name: string;
        };
        type: string;
    }) => void;
    updaetInput: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, path, input } }: {
        payload: {
            id: string;
            path: string[];
            input: string;
        };
        type: string;
    }) => void;
    setOutput: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, path, output } }: {
        payload: {
            id: string;
            path: string[];
            output: string;
        };
        type: string;
    }) => void;
    setError: (state: import("immer/dist/internal").WritableDraft<{
        sessions: Session[];
        activeSessionId: string;
    }>, { payload: { id, path, error } }: {
        payload: {
            id: string;
            path: string[];
            error: string | null;
        };
        type: string;
    }) => void;
}>;
export declare const sessionsReducer: import("@reduxjs/toolkit").Reducer<{
    sessions: Session[];
    activeSessionId: string;
}, import("@reduxjs/toolkit").AnyAction>;
export declare const selectCount: (state: RootState) => Session[];
//# sourceMappingURL=sessionsSlice.d.ts.map